@@ -1,14 +1,38 @@
+/*
+Copyright (C) 1993, 1996, 1997, 2008, 2009, 2010 Free Software Foundation, Inc.
+
+This file is part of the GNU Accounting Utilities
+
+The GNU Accounting Utilities are free software; you can redistribute
+them and/or modify them under the terms of the GNU General Public
+License as published by the Free Software Foundation; either version
+3, or (at your option) any later version.
+
+The GNU Accounting Utilities are distributed in the hope that they will
+be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
+of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with the GNU Accounting Utilities; see the file COPYING.  If
+not, write to the Free Software Foundation, 675 Mass Ave, Cambridge,
+MA 02139, USA.
+*/
+
 /* utmp_rd.h
  *
  * protos & etc. for routines that read from utmp files
  *
  */
 
-#include "config.h"		/* for HAVE_UT_HOST */
+#ifndef UTMP_RD_H
+#define UTMP_RD_H
+
+#include "config.h"		/* for HAVE_STRUCT_UTMP_UT_HOST */
 
 #include "files.h"
 
-#ifdef HAVE_UT_ADDR
+#ifdef HAVE_STRUCT_UTMP_UT_ADDR
 # include <sys/socket.h>
 # include <netinet/in.h>
 # include <arpa/inet.h>		/* for INET_NTOA */
@@ -21,13 +45,13 @@ extern struct utmp utmp_rd_never_used;
 #define NAME_LEN ((int) sizeof (utmp_rd_never_used.ut_name))
 #define TTY_LEN ((int) sizeof (utmp_rd_never_used.ut_line))
 
-#ifdef HAVE_UT_HOST
+#ifdef HAVE_STRUCT_UTMP_UT_HOST
 #define HOST_LEN ((int) sizeof (utmp_rd_never_used.ut_host))
 #else
 #define HOST_LEN 0
 #endif
 
-#ifdef HAVE_UT_ID
+#ifdef HAVE_STRUCT_UTMP_UT_ID
 #define ID_LEN ((int) sizeof (utmp_rd_never_used.ut_id))
 #endif
 
@@ -45,7 +69,7 @@ extern struct utmp utmp_rd_never_used;
 #define NEW_TIME_CHAR '{'
 #define BOOT_TIME_CHAR '~'
 
-#ifdef HAVE_UT_TYPE
+#ifdef HAVE_STRUCT_UTMP_UT_TYPE
 
 #define RECORD_TYPE ut_type
 
@@ -70,8 +94,9 @@ struct utmp *utmp_get_entry PARAMS((void));
 void print_utmp_record PARAMS((struct utmp *rec, FILE *out));
 void utmp_print_file_and_line PARAMS((FILE *out));
 
-#ifdef HAVE_UT_TYPE
+#ifdef HAVE_STRUCT_UTMP_UT_TYPE
 int fix_ut_type_field PARAMS((struct utmp *rec));
 #endif
 
 int bad_utmp_record PARAMS((struct utmp *rec));
+#endif /* UTMP_RD_H */
